@@ -4,16 +4,17 @@
 
 MaxArrayDataLen=8640 #(1 value/10sec for 24h), 6*24*60
 
-arrData=[[0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen,        [0]*MaxArrayDataLen ,             [0]*MaxArrayDataLen]  
+arrData=[[0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen, [0]*MaxArrayDataLen]  
 #field 1:
     # samples
 #field 2:
-    # Time
-    # X movements
-    # Y movement
-    # Summ of X+Y Derivation
-    # Time since last movement over treshhold
-    # Event notes
+    #0 Time
+    #1 X movements
+    #2 Y movement
+    #3 Sum of X+Y Derivation
+    #4 Time since last movement over treshhold
+    #5 Event notes
+    #6 Transformed
 
 
 Index=-1
@@ -33,7 +34,6 @@ arrStatData=[[0]*4,  [0]*4,  [0]*4,  [0]*4]
 
 
 
-
 StartTime_tuple=-1
 StartTime_seconds=-1
 
